@@ -100,7 +100,9 @@
 #' 			\item{seq.useAdaptiveRoi}{[\code{FALSE}] use region of intereset adaptation}
 #' 			\item{meta.keepAllFiles}{[\code{FALSE}] Meta optimization produces lots of temporary files - to keep these files for analysis this switch must be set to TRUE}
 #'			\item{report.func}{[\code{"spotReportDefault"}] name of the function providing the report (default="spotReportDefault" Please also see the notes SPOT - extensions }
-#'			\item{report.path}{[\code{NA} defaults to \code{srcPath}] path where to find the <report.path.func>.R -file}
+#'			\item{report.meta.func}{[\code{"spotReportMetaDefault"}] name of the function providing the report for meta runs, do not use these functions for \code{report.func}.}
+#'			\item{report.path}{[\code{NA} defaults to \code{srcPath}] path where to find the <report.func>.R -file}
+#'			\item{report.meta.path}{[\code{NA} defaults to \code{srcPath}] path where to find the <report.meta.func>.R -file}
 #' 			\item{report.hist}{[\code{0}] report should hold a histogramme (0=no, 1=yes)}
 #' 			\item{report.scatter}{[\code{0}] report should hold a scatterplot (0=no, 1=yes)}
 #' 			\item{report.io.screen}{[\code{FALSE}] report graphics will be printed to screen (FALSE=no, TRUE=yes)}
@@ -265,7 +267,9 @@ spotGetOptions <- function( srcPath=".",configFileName) {
 	## added report.func for the report step 
 	## set default values to "spotDefaultReport" 
 	report.path = NA
+	report.meta.path = NA
 	report.func = "spotReportDefault";
+	report.meta.func = "spotReportMetaDefault";
 	### generate simple histogram in report (0=no, 1 = yes, default =0):
 	report.hist = 0;
 	### generate simple scatterplot in report (0=no, 1 = yes, default =0):
@@ -384,6 +388,9 @@ spotGetOptions <- function( srcPath=".",configFileName) {
 	if(is.na(report.path)){
 		report.path = srcPath ;
 	}
+	if(is.na(report.meta.path)){
+		report.meta.path = srcPath ;
+	}
 	
 	writeLines("spotGetOptions finished", con=stderr());
 	## generate a list of ALL the defined variables (default AND user written = sourced by .conf-file!)
